Stan Math Library: stan/math/prim/mat/fun/mdivide_right_tri.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

mdivide_right_tri.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_FUN_MDIVIDE_RIGHT_TRI_HPP
2 #define STAN_MATH_PRIM_MAT_FUN_MDIVIDE_RIGHT_TRI_HPP
3
4 #include <stan/math/prim/mat/fun/Eigen.hpp>
5 #include <stan/math/prim/mat/fun/mdivide_left_tri.hpp>
6 #include <stan/math/prim/mat/fun/transpose.hpp>
7 #include <stan/math/prim/mat/err/check_multiplicable.hpp>
8 #include <stan/math/prim/mat/err/check_square.hpp>
9 #include <boost/math/tools/promotion.hpp>
10 #include <stdexcept>
11
12 namespace stan {
13 namespace math {
14
24 template <int TriView, typename T1, typename T2,
25 int R1, int C1, int R2, int C2>
26 inline
27 Eigen::Matrix<typename boost::math::tools::promote_args<T1, T2>::type,
28 R1, C2>
29 mdivide_right_tri(const Eigen::Matrix<T1, R1, C1> &b,
30 const Eigen::Matrix<T2, R2, C2> &A) {
31 stan::math::check_square("mdivide_right_tri", "A", A);
32 stan::math::check_multiplicable("mdivide_right_tri",
33 "b", b,
34 "A", A);
35 // FIXME: This is nice and general but requires some extra memory
36 // and copying.
37 if (TriView == Eigen::Lower) {
38 return transpose(mdivide_left_tri<Eigen::Upper>(transpose(A),
39 transpose(b)));
40 } else if (TriView == Eigen::Upper) {
41 return transpose(mdivide_left_tri<Eigen::Lower>(transpose(A),
42 transpose(b)));
43 } else {
44 throw std::domain_error("triangular view must be Eigen::Lower or "
45 "Eigen::Upper");
46 }
47 }
48
49 }
50 }
51 #endif
stan::math::mdivide_right_tri
Eigen::Matrix< typename boost::math::tools::promote_args< T1, T2 >::type, R1, C2 > mdivide_right_tri(const Eigen::Matrix< T1, R1, C1 > &b, const Eigen::Matrix< T2, R2, C2 > &A)
Returns the solution of the system Ax=b when A is triangular.
Definition: mdivide_right_tri.hpp:29
check_multiplicable.hpp
stan
Definition: log_sum_exp.hpp:8
mdivide_left_tri.hpp
transpose.hpp
stan::math::check_multiplicable
bool check_multiplicable(const char *function, const char *name1, const T1 &y1, const char *name2, const T2 &y2)
Return true if the matrices can be multiplied.
Definition: check_multiplicable.hpp:33
stan::math::domain_error
void domain_error(const char *function, const char *name, const T &y, const char *msg1, const char *msg2)
Throw a domain error with a consistently formatted message.
Definition: domain_error.hpp:32
Eigen.hpp
stan::math::transpose
Eigen::Matrix< T, C, R > transpose(const Eigen::Matrix< T, R, C > &m)
Definition: transpose.hpp:12
stan::math::check_square
bool check_square(const char *function, const char *name, const Eigen::Matrix< T_y, Eigen::Dynamic, Eigen::Dynamic > &y)
Return true if the specified matrix is square.
Definition: check_square.hpp:28
check_square.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.